@@ -11,13 +11,13 @@
 #define VERSION_EXTRA ""
 
 /* Version number of Wireshark and associated utilities */
-#define VERSION "4.6.2"
+#define VERSION "4.6.3"
 #define VERSION_MAJOR 4
 #define VERSION_MINOR 6
-#define VERSION_MICRO 2
+#define VERSION_MICRO 3
 
 /* Version number of Stratoshark and associated utilities */
-#define STRATOSHARK_VERSION "0.9.3rc0-1098-g24d5e2b5a3dc"
+#define STRATOSHARK_VERSION "0.9.3rc0-1152-g648f69f3e168"
 
 #define PLUGIN_PATH_ID "4.6"
 #define VERSION_FLAVOR ""
@@ -62,7 +62,7 @@
 #define HAVE_TZSET 1
 
 /* Define to use the MaxMind DB library */
-/* #undef HAVE_MAXMINDDB */
+#define HAVE_MAXMINDDB 1
 /* MaxmindDB version */
 #define MAXMINDDB_VERSION ""
 
@@ -80,7 +80,7 @@
 #define HAVE_GETIFADDRS 1
 
 /* Define if LIBSSH support is enabled */
-/* #undef HAVE_LIBSSH */
+#define HAVE_LIBSSH 1
 
 /* Define if you have the 'dlget' function. */
 /* #undef HAVE_DLGET */
@@ -92,16 +92,16 @@
 /* #undef HAVE_HEIMDAL_KERBEROS */
 
 /* Define to 1 if you have the `krb5_pac_verify' function. */
-/* #undef HAVE_KRB5_PAC_VERIFY */
+#define HAVE_KRB5_PAC_VERIFY 1
 
 /* Define to 1 if you have the `krb5_c_fx_cf2_simple' function. */
-/* #undef HAVE_KRB5_C_FX_CF2_SIMPLE */
+#define HAVE_KRB5_C_FX_CF2_SIMPLE 1
 
 /* Define to 1 if you have the `decode_krb5_enc_tkt_part' function. */
-/* #undef HAVE_DECODE_KRB5_ENC_TKT_PART */
+#define HAVE_DECODE_KRB5_ENC_TKT_PART 1
 
 /* Define to 1 if you have the `encode_krb5_enc_tkt_part' function. */
-/* #undef HAVE_ENCODE_KRB5_ENC_TKT_PART */
+#define HAVE_ENCODE_KRB5_ENC_TKT_PART 1
 
 /* Define to 1 if you have the `inflatePrime' function. */
 #define HAVE_INFLATEPRIME 1
@@ -113,13 +113,13 @@
 /* #undef HAVE_ISSETUGID */
 
 /* Define to use kerberos */
-/* #undef HAVE_KERBEROS */
+#define HAVE_KERBEROS 1
 
 /* Define to use nghttp2 */
-/* #undef HAVE_NGHTTP2 */
+#define HAVE_NGHTTP2 1
 
 /* Define to use nghttp3 */
-/* #undef HAVE_NGHTTP3 */
+#define HAVE_NGHTTP3 1
 
 /* Define to use the libcap library */
 #define HAVE_LIBCAP 1
@@ -140,10 +140,10 @@
 #define HAVE_LIBPCAP 1
 
 /* Define to 1 if you have the `smi' library (-lsmi). */
-/* #undef HAVE_LIBSMI */
+#define HAVE_LIBSMI 1
 
 /* Define to 1 if libsmi exports a version string (and that symbol is visible). */
-/* #undef HAVE_SMI_VERSION_STRING */
+#define HAVE_SMI_VERSION_STRING 1
 
 /* Define to use xxhash library */
 #define HAVE_XXHASH 1
@@ -168,17 +168,17 @@
 /* #undef HAVE_MZCOMPAT_DOS_DATE */
 
 /* Define to use brotli library */
-/* #undef HAVE_BROTLI */
+#define HAVE_BROTLI 1
 
 /* Define to use lz4 library */
-/* #undef HAVE_LZ4 */
+#define HAVE_LZ4 1
 
 /* Check for lz4frame */
-/* #undef HAVE_LZ4FRAME_H */
+#define HAVE_LZ4FRAME_H 1
 
 /* Define to use snappy library */
-/* #undef HAVE_SNAPPY */
-#define SNAPPY_VERSION ""
+#define HAVE_SNAPPY 1
+#define SNAPPY_VERSION "1.2.2"
 
 /* Define to use zstd library */
 #define HAVE_ZSTD 1
@@ -199,7 +199,7 @@
 /* #undef LUA_INTEGER_SIZE */
 
 /* Define to use MIT kerberos */
-/* #undef HAVE_MIT_KERBEROS */
+#define HAVE_MIT_KERBEROS 1
 
 /* Define to 1 if you have the <netdb.h> header file. */
 #define HAVE_NETDB_H 1
@@ -244,22 +244,22 @@
 #define HAVE_PWD_H 1
 
 /* Define to 1 if you want to playing SBC by standalone BlueZ SBC library */
-/* #undef HAVE_SBC */
+#define HAVE_SBC 1
 
 /* Define to 1 if you have the SpanDSP library. */
-/* #undef HAVE_SPANDSP */
+#define HAVE_SPANDSP 1
 
 /* Define to 1 if you have the bcg729 library. */
-/* #undef HAVE_BCG729 */
+#define HAVE_BCG729 1
 
 /* Define to 1 if you have the opencore-amrnb library. */
-/* #undef HAVE_AMRNB */
+#define HAVE_AMRNB 1
 
 /* Define to 1 if you have the ilbc library. */
-/* #undef HAVE_ILBC */
+#define HAVE_ILBC 1
 
 /* Define to 1 if you have the opus library. */
-/* #undef HAVE_OPUS */
+#define HAVE_OPUS 1
 
 /* Define to 1 if you have the `setresgid' function. */
 #define HAVE_SETRESGID 1
